You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficserver.apache.org by am...@apache.org on 2010/10/22 18:05:02 UTC

svn commit: r1026389 [2/4] - in /trafficserver/traffic/branches/wccp: ./ contrib/perl/AdminClient/lib/Apache/TS/ doc/man/ iocore/dns/ iocore/eventsystem/ iocore/utils/ libinktomi++/ proxy/ proxy/api/ts/ proxy/config/ proxy/congest/ proxy/hdrs/ proxy/ht...

Modified: trafficserver/traffic/branches/wccp/proxy/http2/HttpTransactHeaders.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/http2/HttpTransactHeaders.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/http2/HttpTransactHeaders.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/http2/HttpTransactHeaders.h Fri Oct 22 16:05:00 2010
@@ -89,7 +89,7 @@ public:
   static void insert_server_header_in_response(const char *server_tag, int server_tag_size, HTTPHdr * header);
   static void insert_via_header_in_request(HttpConfigParams * http_config_param, int scheme,
                                            HttpTransact::CacheLookupInfo * cache_info, HTTPHdr * header,
-                                           char *incoming_via, int proxy_ip_address);
+                                           char *incoming_via);
   static void insert_via_header_in_response(HttpConfigParams * http_config_param, int scheme,
                                             HttpTransact::CacheLookupInfo * cache_info,
                                             HTTPHdr * header, char *incoming_via);

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/AddConfigFilesHere.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/AddConfigFilesHere.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/AddConfigFilesHere.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/AddConfigFilesHere.cc Fri Oct 22 16:05:00 2010
@@ -80,18 +80,13 @@ initializeRegistry()
   configFiles->addFile("mgmt_allow.config", false);
   configFiles->addFile("ip_allow.config", false);
   configFiles->addFile("parent.config", false);
-  configFiles->addFile("filter.config", false);
   configFiles->addFile("remap.config", false);
   configFiles->addFile("update.config", false);
   configFiles->addFile("admin_access.config", false);
   configFiles->addFile("partition.config", false);
   configFiles->addFile("hosting.config", false);
-  configFiles->addFile("bypass.config", false);
   configFiles->addFile("congestion.config", false);
   configFiles->addFile("plugin.config", false);
-  configFiles->addFile("ipnat.conf", false);
-  configFiles->addFile("bypass.config", false);
-
   configFiles->addFile("splitdns.config", false);
   configFiles->addFile("ssl_multicert.config", false);
   configFiles->addFile("stats.config.xml", false);

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.cc Fri Oct 22 16:05:00 2010
@@ -1063,76 +1063,6 @@ LocalManager::processEventQueue()
 
 }                               /* End LocalManager::processEventQueue */
 
-void
-LocalManager::convert_filters()
-{
-  // do filter_to_policy conversion before TS is launched
-  int status;
-  pid_t convert_pid;
-  bool found;
-  RecInt convert_on = REC_readInteger("proxy.config.auth.convert_filter_to_policy", &found);
-  ink_debug_assert(found);
-
-  if (convert_on) {
-    RecString convert_bin = REC_readString("proxy.config.auth.convert_bin", &found);
-    ink_debug_assert(found);
-
-    const size_t absolute_convert_binary_size = (sizeof(char) * (strlen(bin_path) + strlen(convert_bin)) + 2);
-    char *absolute_convert_binary = (char *) alloca(absolute_convert_binary_size);
-    snprintf(absolute_convert_binary, absolute_convert_binary_size, "%s/%s", bin_path, convert_bin);
-
-    // check that the binary exists
-    if (access(absolute_convert_binary, R_OK | X_OK) == -1) {
-      mgmt_elog(stderr,
-                "[LocalManager::startProxy] "
-                "%s cannot be executed because it does not exist", absolute_convert_binary);
-    } else {
-#ifdef POSIX_THREAD
-      if ((convert_pid = fork()) < 0)
-#else
-      if ((convert_pid = fork1()) < 0)
-#endif
-      {
-        mgmt_elog(stderr, "[LocalManager::startProxy] " "Unable to fork1 process for %s", absolute_convert_binary);
-
-      } else if (convert_pid > 0) {     /* Parent */
-        bool script_done = false;
-        time_t timeout = 10;
-        time_t time_delta = 0;
-        time_t first_time = time(0);
-
-        while (time_delta <= timeout) {
-          if (waitpid(convert_pid, &status, WNOHANG) != 0) {
-            Debug("lm-filter", "[LocalManager::startProxy] " "child pid %d has status", convert_pid);
-            script_done = true;
-            break;
-          }
-          time_delta = time(0) - first_time;
-        }
-
-        // need to kill the child script process if it's not complete
-        if (!script_done) {
-          Debug("lm-filter", "[LocalManager::startProxy] " "kill filter_to_policy (child pid %d)", convert_pid);
-          mgmt_elog(stderr, "[LocalManager::startProxy] "
-                    "%s failed to complete successfully.", absolute_convert_binary);
-          kill(convert_pid, SIGKILL);
-          waitpid(convert_pid, &status, 0);     // to reap the thread
-        } else {
-          Debug("lm-filter", "[LocalManager::startProxy] " "%s execution completed\n", absolute_convert_binary);
-        }
-      } else {                  // invoke the converter script - no args
-        int res = execl(absolute_convert_binary, convert_bin, NULL, (char*)NULL);
-        if (res < 0) {
-          mgmt_elog(stderr, "[LocalManager::startProxy] "
-                    "%s failed to execute successfully.", absolute_convert_binary);
-        }
-        _exit(res);
-      }
-      if (convert_bin)
-        xfree(convert_bin);
-    }
-  }
-}
 
 /*
  * startProxy()
@@ -1147,7 +1077,6 @@ LocalManager::startProxy()
   }
   mgmt_log(stderr, "[LocalManager::startProxy] Launching ts process\n");
 
-  convert_filters();
 
   // INKqa10742
   plugin_list.clear();

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/LocalManager.h Fri Oct 22 16:05:00 2010
@@ -112,7 +112,6 @@ public:
   void processBounce();
   void rollLogFiles();
   void clearStats();
-  void convert_filters();
 
   bool processRunning();
   bool clusterOk();

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/Main.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/Main.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/Main.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/Main.cc Fri Oct 22 16:05:00 2010
@@ -1282,10 +1282,6 @@ fileUpdated(char *fname)
   } else if (strcmp(fname, "cache.config") == 0) {
     lmgmt->signalFileChange("proxy.config.cache.control.filename");
 
-  } else if (strcmp(fname, "filter.config") == 0) {
-    lmgmt->convert_filters();
-    lmgmt->signalFileChange("proxy.config.content_filter.filename");
-
   } else if (strcmp(fname, "parent.config") == 0) {
     lmgmt->signalFileChange("proxy.config.http.parent_proxy.file");
 
@@ -1345,8 +1341,6 @@ fileUpdated(char *fname)
   } else if (strcmp(fname, "logs_xml.config") == 0) {
     lmgmt->signalFileChange("proxy.config.log2.xml_config_file");
 
-
-// INKqa10113
   } else if (strcmp(fname, "splitdns.config") == 0) {
     mgmt_log(stderr, "[fileUpdated] splitdns.config file has been modified\n");
 
@@ -1356,10 +1350,6 @@ fileUpdated(char *fname)
   } else if (strcmp(fname, "ssl_multicert.config") == 0) {
     mgmt_log(stderr, "[fileUpdated] ssl_multicert.config file has been modified\n");
 
-  } else if (strcmp(fname, "ipnat.conf") == 0) {
-    mgmt_log(stderr, "[fileUpdated] ipnat.conf file has been modified\n");
-
-// INKqa11910
   } else if (strcmp(fname, "proxy.config.body_factory.template_sets_dir") == 0) {
     lmgmt->signalFileChange("proxy.config.body_factory.template_sets_dir");
 

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/Makefile.am
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/Makefile.am?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/Makefile.am (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/Makefile.am Fri Oct 22 16:05:00 2010
@@ -36,8 +36,7 @@ AM_CPPFLAGS = \
   -I$(top_srcdir)/proxy/mgmt2/preparse \
   -I$(top_srcdir)/proxy/mgmt2/stats \
   -I$(top_srcdir)/proxy/mgmt2/utils \
-  -I$(top_srcdir)/proxy/mgmt2/web2 \
-  -DPKGSYSUSER=\"$(pkgsysuser)\"
+  -I$(top_srcdir)/proxy/mgmt2/web2
 
 MGMT_DEFS = @MGMT_DEFS@
 DEFS += $(MGMT_DEFS)

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/RecordsConfig.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/RecordsConfig.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/RecordsConfig.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/RecordsConfig.cc Fri Oct 22 16:05:00 2010
@@ -83,7 +83,7 @@ RecordElement RecordsConfig[] = {
   ,
   {CONFIG, "proxy.config.temp_dir", "", INK_STRING, "/tmp", RU_NULL, RR_NULL, RC_NULL, NULL, RA_NULL}
   ,
-  {CONFIG, "proxy.config.alarm_email", "", INK_STRING, PKGSYSUSER, RU_REREAD, RR_NULL, RC_STR, ".*", RA_NULL}
+  {CONFIG, "proxy.config.alarm_email", "", INK_STRING, TS_PKGSYSUSER, RU_REREAD, RR_NULL, RC_STR, ".*", RA_NULL}
   ,
   {CONFIG, "proxy.config.syslog_facility", "", INK_STRING, "LOG_DAEMON", RU_NULL, RR_NULL, RC_NULL, NULL, RA_NULL}
   ,
@@ -355,7 +355,7 @@ RecordElement RecordsConfig[] = {
   ,
   {CONFIG, "proxy.config.admin.number_config_bak", "", INK_INT, "3", RU_NULL, RR_NULL, RC_NULL, NULL, RA_NULL}
   ,
-  {CONFIG, "proxy.config.admin.user_id", "", INK_STRING, PKGSYSUSER, RU_NULL, RR_REQUIRED, RC_NULL, NULL, RA_NULL}
+  {CONFIG, "proxy.config.admin.user_id", "", INK_STRING, TS_PKGSYSUSER, RU_NULL, RR_REQUIRED, RC_NULL, NULL, RA_NULL}
   ,
   {CONFIG, "proxy.config.admin.ui_refresh_rate", "", INK_INT, "30", RU_REREAD, RR_NULL, RC_NULL, NULL, RA_NULL}
   ,
@@ -548,47 +548,6 @@ RecordElement RecordsConfig[] = {
   {CONFIG, "proxy.config.header.parse.no_host_url_redirect", "", INK_STRING, NULL, RU_REREAD, RR_NULL, RC_STR, ".*",
    RA_NULL}
   ,
-  //##############################################################################
-  //#
-  //# Authentication Basic Realm
-  //##############################################################################
-  {CONFIG, "proxy.config.auth.enabled", "", INK_INT, "0",
-   RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.auth.cache.filename", "", INK_STRING,
-   "authcache.db", RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.auth.cache.path", "", INK_STRING,
-   "/var/trafficserver", RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.auth.cache.size", "", INK_INT, "5000",
-   RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.auth.cache.storage_size", "", INK_INT, "15728640",
-   RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.http.auth.flags", "", INK_INT, "0",
-   RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.http.auth.scope", "", INK_STRING,
-   "TE", RU_REREAD, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.http.auth.authenticate_session", "", INK_INT,
-   "0", RU_RESTART_TS, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.proxy.authenticate.basic.realm", "",
-   INK_STRING, NULL, RU_REREAD, RR_NULL, RC_NULL, NULL, RA_NULL}
-  ,
-  {CONFIG, "proxy.config.auth.convert_filter_to_policy", "", INK_INT, "0", RU_RESTART_TS, RR_NULL, RC_INT, "[0-1]",
-   RA_NULL}
-  ,
-  // assumes executable is stored in bin_path directory
-  {CONFIG, "proxy.config.auth.convert_bin", "", INK_STRING, "filter_to_policy", RU_REREAD, RR_NULL, RC_STR, ".*",
-   RA_NULL}
-  ,
-  {CONFIG, "proxy.config.auth.password_file_path", "", INK_STRING, "var/trafficserver", RU_REREAD, RR_NULL, RC_NULL,
-   ".*", RA_NULL}
-  ,
 
 //
 // congestion control
@@ -2406,14 +2365,6 @@ RecordElement RecordsConfig[] = {
   ,
   //##############################################################################
   //#
-  //# Content Filtering
-  //#
-  //##############################################################################
-  {CONFIG, "proxy.config.content_filter.filename", "", INK_STRING, "filter.config", RU_RESTART_TS, RR_NULL, RC_NULL,
-   NULL, RA_NULL}
-  ,
-  //##############################################################################
-  //#
   //# Reverse Proxy
   //#
   //##############################################################################

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.cc Fri Oct 22 16:05:00 2010
@@ -627,426 +627,6 @@ CongestionObj::getCfgEleCopy()
   return (INKCfgEle *) copy_congestion_ele(m_ele);
 }
 
-//--------------------------------------------------------------------------
-// FilterObj
-//--------------------------------------------------------------------------
-FilterObj::FilterObj(INKFilterEle * ele)
-{
-  m_ele = ele;
-  m_valid = true;
-  m_valid = isValid();
-}
-
-FilterObj::FilterObj(TokenList * tokens)
-{
-  Token *tok;
-
-  m_ele = INKFilterEleCreate(INK_TYPE_UNDEFINED);
-  m_ele->cfg_ele.error = INK_ERR_OKAY;
-  m_valid = true;
-
-  if (!tokens)
-    goto FORMAT_ERR;
-
-  // set ele type
-  m_ele->cfg_ele.type = get_rule_type(tokens, INK_FNAME_FILTER);
-  if (m_ele->cfg_ele.type == INK_TYPE_UNDEFINED)
-    goto FORMAT_ERR;
-
-  tok = tokens->first();
-  tok = tokens_to_pdss_format(tokens, tok, &(m_ele->filter_info));
-  if (!tok)
-    goto FORMAT_ERR;
-
-
-  // must have another token
-  tok = tokens->next(tok);
-  if (!tok || !tok->value)
-    goto FORMAT_ERR;
-
-  // Some sanity check
-  if ((strcmp(tok->name, "action") != 0) &&
-      (strcmp(tok->name, "keep_hdr") != 0) && (strcmp(tok->name, "strip_hdr") != 0))
-    goto FORMAT_ERR;
-
-  if (strcmp(tok->name, "action") == 0) {
-    if ((strcmp(tok->value, "allow") != 0) &&
-        (strcmp(tok->value, "deny") != 0) &&
-        (strcmp(tok->value, "ldap") != 0) && (strcmp(tok->value, "ntlm") != 0) && (strcmp(tok->value, "radius") != 0))
-      goto FORMAT_ERR;
-
-  } else {                      // tok->name must either be keep_hdr or strip_hdr.
-    if (strcmp(tok->value, "date") == 0) {
-      m_ele->hdr = INK_HDR_DATE;
-    } else if (strcmp(tok->value, "host") == 0) {
-      m_ele->hdr = INK_HDR_HOST;
-    } else if (strcmp(tok->value, "cookie") == 0) {
-      m_ele->hdr = INK_HDR_COOKIE;
-    } else if (strcmp(tok->value, "client_ip") == 0) {
-      m_ele->hdr = INK_HDR_CLIENT_IP;
-    } else {
-      m_ele->hdr = INK_HDR_UNDEFINED;
-      goto FORMAT_ERR;
-    }
-  }
-
-  if (m_ele->cfg_ele.type == INK_FILTER_LDAP ||
-      m_ele->cfg_ele.type == INK_FILTER_NTLM || m_ele->cfg_ele.type == INK_FILTER_RADIUS) {
-    tok = tokens->next(tok);
-    while (tok) {
-      if (!strcmp(tok->name, "server")) {
-        if ((!tok->value) || (m_ele->server)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->server = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "dn")) {
-        if ((!tok->value) || (m_ele->dn)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->dn = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "realm")) {
-        if ((!tok->value) || (m_ele->realm)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->realm = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "uid_filter")) {
-        if ((!tok->value) || (m_ele->uid_filter)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->uid_filter = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "attr")) {
-        if ((!tok->value) || (m_ele->attr)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->attr = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "attr_val")) {
-        if ((!tok->value) || (m_ele->attr_val)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->attr_val = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "redirect_url")) {
-        if ((!tok->value) || (m_ele->redirect_url)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->redirect_url = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "bind_dn")) {
-        if ((!tok->value) || (m_ele->bind_dn)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->bind_dn = xstrdup(tok->value);
-      } else if (!strcmp(tok->name, "bind_pwd_file")) {
-        if ((!tok->value) || (m_ele->bind_pwd_file)) {
-          goto FORMAT_ERR;
-        }
-        m_ele->bind_pwd_file = xstrdup(tok->value);
-      } else {
-        goto FORMAT_ERR;
-      }
-      tok = tokens->next(tok);
-    }
-  } else {
-    // Sanity check -- should have no more token
-    if (tokens->next(tok)) {
-      goto FORMAT_ERR;
-    }
-  }
-
-  return;
-
-FORMAT_ERR:
-  m_ele->cfg_ele.error = INK_ERR_INVALID_CONFIG_RULE;
-  m_valid = false;
-}
-
-FilterObj::~FilterObj()
-{
-  INKFilterEleDestroy(m_ele);
-}
-
-char *
-FilterObj::formatEleToRule()
-{
-  if (!isValid()) {
-    m_ele->cfg_ele.error = INK_ERR_INVALID_CONFIG_RULE;
-    return NULL;
-  }
-
-  char *pd_str;
-  char buf[MAX_RULE_SIZE];
-  size_t buf_pos = 0;
-  int psize;
-
-  memset(buf, 0, MAX_RULE_SIZE);
-
-  pd_str = pdest_sspec_to_string(m_ele->filter_info.pd_type, m_ele->filter_info.pd_val, &(m_ele->filter_info.sec_spec));
-  if (!pd_str) {
-    return NULL;
-  }
-
-  if (buf_pos<sizeof(buf) && (psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "%s", pd_str))> 0)
-    buf_pos += psize;
-
-  xfree(pd_str);
-
-  if (buf_pos < sizeof(buf)) {
-    switch (m_ele->cfg_ele.type) {
-    case INK_FILTER_ALLOW:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "action=allow");
-      break;
-    case INK_FILTER_DENY:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "action=deny");
-      break;
-    case INK_FILTER_LDAP:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "action=ldap");
-      break;
-    case INK_FILTER_NTLM:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "action=ntlm");
-      break;
-    case INK_FILTER_RADIUS:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "action=radius");
-      break;
-    case INK_FILTER_KEEP_HDR:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "keep_hdr=");
-      break;
-    case INK_FILTER_STRIP_HDR:
-      psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "strip_hdr=");
-      break;
-    default:
-      psize = 0;
-      // Handled here:
-      // Lots of cases ...
-      break;
-    }
-    if (psize > 0)
-      buf_pos += psize;
-  }
-  // Just for keep_hdr or strip_hdr
-  if (buf_pos < sizeof(buf)) {
-    switch (m_ele->cfg_ele.type) {
-    case INK_FILTER_KEEP_HDR:
-    case INK_FILTER_STRIP_HDR:
-      switch (m_ele->hdr) {
-      case INK_HDR_DATE:
-        psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "date");
-        break;
-      case INK_HDR_HOST:
-        psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "host");
-        break;
-      case INK_HDR_COOKIE:
-        psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "cookie");
-        break;
-      case INK_HDR_CLIENT_IP:
-        psize = snprintf(buf + buf_pos, sizeof(buf) - buf_pos, "client_ip");
-        break;
-      default:
-        return NULL;
-      }
-    default:
-      psize = 0;
-      break;
-    }
-    if (psize > 0)
-      buf_pos += psize;
-  }
-  // Any LDAP/NTLM specific tag/name
-  if (m_ele->cfg_ele.type == INK_FILTER_LDAP ||
-      m_ele->cfg_ele.type == INK_FILTER_NTLM || m_ele->cfg_ele.type == INK_FILTER_RADIUS) {
-    if (m_ele->server) {
-      char *temp = m_ele->server;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " server=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->server, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->dn) {
-      char *temp = m_ele->dn;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " dn=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->dn, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->realm) {
-      char *temp = m_ele->realm;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " realm=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->realm, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->uid_filter) {
-      char *temp = m_ele->uid_filter;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " uid_filter=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->uid_filter, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->attr) {
-      char *temp = m_ele->attr;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " attr=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->attr, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->attr_val) {
-      char *temp = m_ele->attr_val;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " attr_val=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->attr_val, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->redirect_url) {
-      char *temp = m_ele->redirect_url;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " redirect_url=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->redirect_url, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->bind_dn) {
-      char *temp = m_ele->bind_dn;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " bind_dn=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->bind_dn, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-    if (m_ele->bind_pwd_file) {
-      char *temp = m_ele->bind_pwd_file;
-      bool quoteNeeded = (strstr(temp, " ") || strstr(temp, "="));
-      strncat(buf, " bind_pwd_file=", sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-      strncat(buf, m_ele->bind_pwd_file, sizeof(buf) - strlen(buf) - 1);
-      if (quoteNeeded) {
-        strncat(buf, "\"", sizeof(buf) - strlen(buf) - 1);
-      }
-    }
-  }
-  return xstrdup(buf);
-}
-
-bool FilterObj::isValid()
-{
-  if (m_ele->cfg_ele.error != INK_ERR_OKAY) {
-    m_valid = false;
-  }
-
-  if (!ccu_checkPdSspec(m_ele->filter_info)) {
-    m_valid = false;
-  }
-
-  switch (m_ele->cfg_ele.type) {
-  case INK_FILTER_KEEP_HDR:
-  case INK_FILTER_STRIP_HDR:
-    switch (m_ele->hdr) {
-    case INK_HDR_DATE:
-    case INK_HDR_HOST:
-    case INK_HDR_COOKIE:
-    case INK_HDR_CLIENT_IP:
-      break;
-    default:
-      m_valid = false;
-    }
-    break;
-  case INK_FILTER_ALLOW:
-  case INK_FILTER_DENY:
-  case INK_FILTER_RADIUS:
-    if (m_ele->hdr != INK_HDR_UNDEFINED)
-      m_valid = false;
-    break;
-  case INK_FILTER_NTLM:
-  case INK_FILTER_LDAP:
-    // if ldap server is specified, uid-filter, base-dn must be too
-    if (m_ele->server || m_ele->dn || m_ele->uid_filter) {
-      if (!m_ele->server || !m_ele->dn || !m_ele->uid_filter) {
-        m_valid = false;
-      }
-    }
-    break;
-  default:
-    m_valid = false;
-  }
-
-
-  // if one or more of LDAP action optional parameters is specified:
-  // (1) must be LDAP or NTLM rule
-  // (1) if LDAP rule, server=, dn=, uid_filter= must be present
-  if (m_ele->attr || m_ele->attr_val || m_ele->bind_dn || m_ele->bind_pwd_file) {
-    if (m_ele->cfg_ele.type != INK_FILTER_LDAP && m_ele->cfg_ele.type != INK_FILTER_NTLM) {
-      m_valid = false;
-    }
-    if (m_ele->cfg_ele.type == INK_FILTER_LDAP) {
-      if ((!m_ele->dn) || (!m_ele->server) || (!m_ele->uid_filter)) {
-        m_valid = false;
-      }
-    }
-  }
-  // realm and redirect_url can only be specified for LDAP, radius or NTLM rules
-  if (m_ele->realm || m_ele->redirect_url) {
-    if (m_ele->cfg_ele.type != INK_FILTER_LDAP &&
-        m_ele->cfg_ele.type != INK_FILTER_NTLM && m_ele->cfg_ele.type != INK_FILTER_RADIUS) {
-      m_valid = false;
-    }
-    if (m_ele->cfg_ele.type == INK_FILTER_LDAP && (!m_ele->dn || !m_ele->server || !m_ele->uid_filter)) {
-      m_valid = false;
-    }
-  }
-  // bind_dn and bind_pwd_file must both be specified
-  if (m_ele->bind_dn || m_ele->bind_pwd_file) {
-    if (!m_ele->bind_dn || !m_ele->bind_pwd_file) {
-      m_valid = false;
-    }
-  }
-
-  if (!m_valid)
-    m_ele->cfg_ele.error = INK_ERR_INVALID_CONFIG_RULE;
-
-  return m_valid;
-}
-
-INKCfgEle *
-FilterObj::getCfgEleCopy()
-{
-  return (INKCfgEle *) copy_filter_ele(m_ele);
-}
 
 //--------------------------------------------------------------------------
 // HostingObj
@@ -1933,8 +1513,6 @@ PartitionObj::PartitionObj(TokenList * t
   }
   if (!strcmp(token->value, "http")) {
     m_ele->scheme = INK_PARTITION_HTTP;
-  } else if (!strcmp(token->value, "mixt")) {
-    m_ele->scheme = INK_PARTITION_MIXT;
   } else {
     m_ele->scheme = INK_PARTITION_UNDEFINED;
   }
@@ -1980,9 +1558,6 @@ PartitionObj::formatEleToRule()
   case INK_PARTITION_HTTP:
     strncat(buf, "http", sizeof(buf) - strlen(buf) - 1);
     break;
-  case INK_PARTITION_MIXT:
-    strncat(buf, "mixt", sizeof(buf) - strlen(buf) - 1);
-    break;
   default:
     // Handled here:
     // INK_PARTITION_UNDEFINED, INK_SIZE_FMT_ABSOLUTE, INK_SIZE_FMT_UNDEFINED
@@ -2016,7 +1591,6 @@ bool PartitionObj::isValid()
 
   switch (m_ele->scheme) {
   case INK_PARTITION_HTTP:
-  case INK_PARTITION_MIXT:
     break;
   default:
     m_valid = false;

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextImpl.h Fri Oct 22 16:05:00 2010
@@ -174,30 +174,6 @@ private:
   INKCongestionEle * m_ele;
 };
 
-/* filter.config    *********************************************/
-class FilterObj:public CfgEleObj
-{
-public:
-  FilterObj(INKFilterEle * ele);
-  FilterObj(TokenList * tokens);        //creates the ele
-  ~FilterObj();
-
-  virtual char *formatEleToRule();
-  virtual bool isValid();
-  virtual INKCfgEle *getCfgEleCopy();
-  virtual INKCfgEle *getCfgEle()
-  {
-    return (INKCfgEle *) m_ele;
-  }
-  virtual INKRuleTypeT getRuleType()
-  {
-    return m_ele->cfg_ele.type;
-  }
-
-private:
-  INKFilterEle * m_ele;
-};
-
 /* hosting.config ************************************************/
 class HostingObj:public CfgEleObj
 {

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.cc Fri Oct 22 16:05:00 2010
@@ -1448,9 +1448,6 @@ filename_to_string(INKFileNameT file)
   case INK_FNAME_CONGESTION:
     return xstrdup("congestion.config");
 
-  case INK_FNAME_FILTER:
-    return xstrdup("filter.config");
-
   case INK_FNAME_HOSTING:
     return xstrdup("hosting.config");
 
@@ -1970,15 +1967,6 @@ create_ele_obj_from_rule_node(Rule * rul
   case INK_CONGESTION:
     ele = (CfgEleObj *) new CongestionObj(token_list);
     break;
-  case INK_FILTER_ALLOW:       /* filter.config */
-  case INK_FILTER_DENY:
-  case INK_FILTER_LDAP:
-  case INK_FILTER_NTLM:
-  case INK_FILTER_RADIUS:
-  case INK_FILTER_KEEP_HDR:
-  case INK_FILTER_STRIP_HDR:
-    ele = (CfgEleObj *) new FilterObj(token_list);
-    break;
   case INK_HOSTING:            /* hosting.config */
     ele = (CfgEleObj *) new HostingObj(token_list);
     break;
@@ -2075,16 +2063,6 @@ create_ele_obj_from_ele(INKCfgEle * ele)
     ele_obj = (CfgEleObj *) new CongestionObj((INKCongestionEle *) ele);
     break;
 
-  case INK_FILTER_ALLOW:       /* filter.config */
-  case INK_FILTER_DENY:        // fall-through
-  case INK_FILTER_LDAP:        // fall-through
-  case INK_FILTER_NTLM:        // fall-through
-  case INK_FILTER_RADIUS:      // fall-through
-  case INK_FILTER_KEEP_HDR:    // fall-through
-  case INK_FILTER_STRIP_HDR:   // fall-through
-    ele_obj = (CfgEleObj *) new FilterObj((INKFilterEle *) ele);
-    break;
-
   case INK_HOSTING:            /* hosting.config */
     ele_obj = (CfgEleObj *) new HostingObj((INKHostingEle *) ele);
     break;
@@ -2210,32 +2188,6 @@ get_rule_type(TokenList * token_list, IN
   case INK_FNAME_CONGESTION:   /* congestion.config */
     return INK_CONGESTION;
 
-  case INK_FNAME_FILTER:       /* filter.config */
-    /* action tag should be last token-value pair in TokenList */
-    //tok = token_list->last();
-    for (tok = token_list->first(); tok; tok = token_list->next(tok)) {
-      if (strcmp(tok->name, "action") == 0) {
-        if (strcmp(tok->value, "allow") == 0) {
-          return INK_FILTER_ALLOW;
-        } else if (strcmp(tok->value, "deny") == 0) {
-          return INK_FILTER_DENY;
-        } else if (strcmp(tok->value, "ldap") == 0) {
-          return INK_FILTER_LDAP;
-        } else if (strcmp(tok->value, "ntlm") == 0) {
-          return INK_FILTER_NTLM;
-        } else if (strcmp(tok->value, "radius") == 0) {
-          return INK_FILTER_RADIUS;
-        } else {
-          return INK_TYPE_UNDEFINED;
-        }
-      } else if (strcmp(tok->name, "keep_hdr") == 0) {
-        return INK_FILTER_KEEP_HDR;
-      } else if (strcmp(tok->name, "strip_hdr") == 0) {
-        return INK_FILTER_STRIP_HDR;
-      }
-    }
-    return INK_FILTER_ALLOW;
-
   case INK_FNAME_HOSTING:      /* hosting.config */
     return INK_HOSTING;
 
@@ -2622,42 +2574,6 @@ copy_congestion_ele(INKCongestionEle * e
   return nele;
 }
 
-INKFilterEle *
-copy_filter_ele(INKFilterEle * ele)
-{
-  if (!ele) {
-    return NULL;
-  }
-
-  INKFilterEle *nele = INKFilterEleCreate(INK_TYPE_UNDEFINED);
-  if (!nele)
-    return NULL;
-
-  copy_cfg_ele(&(ele->cfg_ele), &(nele->cfg_ele));
-  copy_pdss_format(&(ele->filter_info), &(nele->filter_info));
-  nele->hdr = ele->hdr;
-  /* LDAP */
-  if (ele->server)
-    nele->server = xstrdup(ele->server);
-  if (ele->dn)
-    nele->dn = xstrdup(ele->dn);
-  if (ele->realm)
-    nele->realm = xstrdup(ele->realm);
-  if (ele->uid_filter)
-    nele->uid_filter = xstrdup(ele->uid_filter);
-  if (ele->attr)
-    nele->attr = xstrdup(ele->attr);
-  if (ele->attr_val)
-    nele->attr_val = xstrdup(ele->attr_val);
-  if (ele->redirect_url)
-    nele->redirect_url = xstrdup(ele->redirect_url);
-  if (ele->bind_dn)
-    nele->bind_dn = xstrdup(ele->bind_dn);
-  if (ele->bind_pwd_file)
-    nele->bind_pwd_file = xstrdup(ele->bind_pwd_file);
-
-  return nele;
-}
 
 INKHostingEle *
 copy_hosting_ele(INKHostingEle * ele)

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/CfgContextUtils.h Fri Oct 22 16:05:00 2010
@@ -177,7 +177,6 @@ INKIntList copy_int_list(INKIntList list
 INKAdminAccessEle *copy_admin_access_ele(INKAdminAccessEle * ele);
 INKCacheEle *copy_cache_ele(INKCacheEle * ele);
 INKCongestionEle *copy_congestion_ele(INKCongestionEle * ele);
-INKFilterEle *copy_filter_ele(INKFilterEle * ele);
 INKHostingEle *copy_hosting_ele(INKHostingEle * ele);
 INKIcpEle *copy_icp_ele(INKIcpEle * ele);
 INKIpAllowEle *copy_ip_allow_ele(INKIpAllowEle * ele);

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.cc Fri Oct 22 16:05:00 2010
@@ -212,8 +212,6 @@ Rule::parse(const char *const_rule, INKF
     return cacheParse(rule);
   case INK_FNAME_CONGESTION:   /* congestion.config */
     return congestionParse(rule, 1, 15);
-  case INK_FNAME_FILTER:       /* filter.config */
-    return filterParse(rule);
   case INK_FNAME_HOSTING:      /* hosting.config */
     return hostingParse(rule);
   case INK_FNAME_ICP_PEER:     /* icp.config */
@@ -303,84 +301,6 @@ Rule::arm_securityParse(char *rule)
 
 
 /**
- * bypassSubParse
- **/
-Token *
-Rule::bypassSubParse(char *rule, unsigned short minNumToken, unsigned short maxNumToken)
-{
-  NOWARN_UNUSED(maxNumToken);
-  Tokenizer ruleTok(" \t");
-  int numRuleTok = ruleTok.Initialize(rule);
-  tok_iter_state ruleTok_state;
-  const char *tokenStr = ruleTok.iterFirst(&ruleTok_state);
-
-  // Sanity Check -- must have more than 2 tokens, otherwise bail out
-  if (numRuleTok < minNumToken) {
-    this->setErrorHint("Extra token(s) expected!");
-    return NULL;
-  }
-
-  Token *token = NEW(new Token());
-  // First token -- either "src" or "dst"
-  token->setName(tokenStr);
-
-  // The rest is an IP address or a list of IP address
-  while ((tokenStr = ruleTok.iterNext(&ruleTok_state))) {
-    token->appendValue(tokenStr);
-  }
-
-  return (token);
-}
-
-
-/**
- * bypassParse
- *   ASSUMPTIONS:
- *     + each token is separated by either "\s", "\t" or ","
- *     + each rule has at least 2 tokens
- **/
-TokenList *
-Rule::bypassParse(char *rule, unsigned short minNumToken, unsigned short maxNumToken)
-{
-  NOWARN_UNUSED(maxNumToken);
-  Tokenizer ruleTok(" \t");
-  int numRuleTok = ruleTok.Initialize(rule);
-  tok_iter_state ruleTok_state;
-  const char *tokenStr = ruleTok.iterFirst(&ruleTok_state);
-
-  // Sanity Check -- must have more than 3 tokens, otherwise bail out
-  if (numRuleTok < minNumToken) {
-    this->setErrorHint("Expecting more tokens");
-    return NULL;
-  }
-  TokenList *m_tokenList = NEW(new TokenList());
-  Token *token = NEW(new Token());
-
-  // First token -- "bypass", no "VALUE"
-  token->setName(tokenStr);
-  m_tokenList->enqueue(token);
-
-  // Skip first token
-  rule += strlen(tokenStr);
-
-  char *andToken = NULL;
-  if (!(andToken = strstr(rule, "AND")) && !(andToken = strstr(rule, "and"))) {
-    // Not an AND rule
-    m_tokenList->enqueue(bypassSubParse(rule));
-  } else {
-
-    // Chop rule into two parts: rule & and
-    rule[strlen(rule) - strlen(andToken)] = '\0';
-
-    m_tokenList->enqueue(bypassSubParse(rule));
-    m_tokenList->enqueue(bypassSubParse(andToken + strlen("AND")));
-  }
-
-  return m_tokenList;
-}
-
-
-/**
  * cacheParse
  * CAUTION: This function is used for number of similar formatted
  *          configureation file parsing. Modification to this function
@@ -490,16 +410,6 @@ Rule::congestionParse(char *rule, unsign
 }
 
 /**
- * filterParse
- **/
-TokenList *
-Rule::filterParse(char *rule)
-{
-  return cacheParse(rule, 2);
-}
-
-
-/**
  * hostingParse
  **/
 TokenList *
@@ -560,38 +470,6 @@ Rule::ip_allowParse(char *rule)
   return cacheParse(rule, 2, 2);
 }
 
-TokenList *
-Rule::ipnatParse(char *rule)
-{
-  Tokenizer ruleTok(" \t");
-  int numRuleTok = ruleTok.Initialize(rule);
-  tok_iter_state ruleTok_state;
-  const char *tokenStr = ruleTok.iterFirst(&ruleTok_state);
-  Token *token;
-
-  if (numRuleTok < 10) {
-    setErrorHint("Expecting at least 10 tokens!");
-    return NULL;
-  }
-
-  TokenList *m_tokenList = NEW(new TokenList());
-
-  while (tokenStr) {
-    token = NEW(new Token());
-    token->setName(tokenStr);
-    tokenStr = ruleTok.iterNext(&ruleTok_state);
-    m_tokenList->enqueue(token);
-  }
-
-  // Just to make sure that there are no left overs
-  // coverity[returned_pointer]
-  tokenStr = ruleTok.iterNext(&ruleTok_state);
-  ink_debug_assert(tokenStr == NULL);
-
-  return m_tokenList;
-}
-
-
 
 /**
  * logsParse
@@ -1094,8 +972,6 @@ RuleList::parse(char *fileBuf, const cha
     m_filetype = INK_FNAME_CACHE_OBJ;   /* cache.config */
   } else if (strstr(filename, "congestion.config")) {
     m_filetype = INK_FNAME_CONGESTION;  /* congestion.config */
-  } else if (strstr(filename, "filter.config")) {
-    m_filetype = INK_FNAME_FILTER;      /* filter.config */
   } else if (strstr(filename, "hosting.config")) {
     m_filetype = INK_FNAME_HOSTING;     /* hosting.config */
   } else if (strstr(filename, "icp.config")) {

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/GenericParser.h Fri Oct 22 16:05:00 2010
@@ -192,19 +192,9 @@ private:
   char *m_errorHint;
   unsigned m_lineNum;
 
-  Token *bypassSubParse(char *rule,
-                        unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
-  TokenList *bypassParse(char *rule,
-                         unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
-  TokenList *cacheParse(char *rule,
-                        unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
-  TokenList *congestionParse(char *rule,
-                             unsigned short minNumToken = MIN_CONFIG_TOKEN,
-                             unsigned short maxNumToken = MAX_CONFIG_TOKEN);
-  TokenList *filterParse(char *rule);
-  TokenList *icpParse(char *rule,
-                      unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
-  TokenList *ipnatParse(char *rule);
+  TokenList *cacheParse(char *rule, unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
+  TokenList *congestionParse(char *rule, unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
+  TokenList *icpParse(char *rule, unsigned short minNumToken = MIN_CONFIG_TOKEN, unsigned short maxNumToken = MAX_CONFIG_TOKEN);
   TokenList *parentParse(char *rule);
   TokenList *remapParse(char *rule);
   TokenList *socksParse(char *rule);

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPI.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPI.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPI.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPI.cc Fri Oct 22 16:05:00 2010
@@ -1070,79 +1070,6 @@ INKCongestionEleDestroy(INKCongestionEle
   return;
 }
 
-/*-------------------------------------------------------------
- * FilterObject
- *-------------------------------------------------------------*/
-inkapi INKFilterEle *
-INKFilterEleCreate(INKRuleTypeT type)
-{
-  INKFilterEle *ele;
-
-  if (type != INK_FILTER_ALLOW &&
-      type != INK_FILTER_DENY &&
-      type != INK_FILTER_LDAP &&
-      type != INK_FILTER_KEEP_HDR && type != INK_FILTER_STRIP_HDR && type != INK_TYPE_UNDEFINED)
-    return NULL;
-
-  ele = (INKFilterEle *) xmalloc(sizeof(INKFilterEle));
-  if (!ele)
-    return NULL;
-
-  /* set defaults */
-  ele->cfg_ele.type = type;
-  ele->cfg_ele.error = INK_ERR_OKAY;
-  init_pdss_format(&(ele->filter_info));
-  ele->hdr = INK_HDR_UNDEFINED;
-  ele->server = NULL;
-  ele->dn = NULL;
-  ele->realm = NULL;
-  ele->uid_filter = NULL;
-  ele->attr = NULL;
-  ele->attr_val = NULL;
-  ele->redirect_url = NULL;
-  ele->bind_dn = NULL;
-  ele->bind_pwd_file = NULL;
-  return ele;
-}
-
-inkapi void
-INKFilterEleDestroy(INKFilterEle * ele)
-{
-  if (ele) {
-    INKPdSsFormatDestroy(&(ele->filter_info));
-    if (ele->server) {
-      xfree(ele->server);
-    }
-    if (ele->dn) {
-      xfree(ele->dn);
-    }
-    if (ele->realm) {
-      xfree(ele->realm);
-    }
-    if (ele->uid_filter) {
-      xfree(ele->uid_filter);
-    }
-    if (ele->attr) {
-      xfree(ele->attr);
-    }
-    if (ele->attr_val) {
-      xfree(ele->attr_val);
-    }
-    if (ele->redirect_url) {
-      xfree(ele->redirect_url);
-    }
-    if (ele->bind_dn) {
-      xfree(ele->bind_dn);
-    }
-    if (ele->bind_pwd_file) {
-      xfree(ele->bind_pwd_file);
-    }
-
-    xfree(ele);
-  }
-  return;
-}
-
 
 /*-------------------------------------------------------------
  * HostingObj

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPIStub.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPIStub.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPIStub.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/INKMgmtAPIStub.cc Fri Oct 22 16:05:00 2010
@@ -355,18 +355,6 @@ INKCongestionEleDestroy(INKCongestionEle
   return;
 }
 
-inkapi INKFilterEle *
-INKFilterEleCreate()
-{
-  return NULL;
-}
-
-inkapi void
-INKFilterEleDestroy(INKFilterEle * ele)
-{
-  return;
-}
-
 inkapi INKHostingEle *
 INKHostingEleCreate()
 {
@@ -391,18 +379,6 @@ INKIcpEleDestory(INKIcpEle * ele)
   return;
 }
 
-inkapi INKIpFilterEle *
-INKIpFilterEleCreate()
-{
-  return NULL;
-}
-
-inkapi void
-INKIpFilterEleDestroy(INKIpFilterEle * ele)
-{
-  return;
-}
-
 inkapi INKLdapSrvrEle *
 INKLdapSrvrEleCreate()
 {

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/include/INKMgmtAPI.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/include/INKMgmtAPI.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/include/INKMgmtAPI.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/include/INKMgmtAPI.h Fri Oct 22 16:05:00 2010
@@ -364,7 +364,6 @@ typedef enum
   typedef enum                  /* possible schemes to divide partition by */
   {
     INK_PARTITION_HTTP,
-    INK_PARTITION_MIXT,
     INK_PARTITION_UNDEFINED
   } INKPartitionSchemeT;
 
@@ -393,7 +392,6 @@ typedef enum
     INK_FNAME_ADMIN_ACCESS,     /* admin_access.config */
     INK_FNAME_CACHE_OBJ,        /* cache.config */
     INK_FNAME_CONGESTION,       /* congestion.config */
-    INK_FNAME_FILTER,           /* filter.config */
     INK_FNAME_HOSTING,          /* hosting.config */
     INK_FNAME_ICP_PEER,         /* icp.config */
     INK_FNAME_IP_ALLOW,         /* ip_allow.config */
@@ -432,13 +430,6 @@ typedef enum
     INK_CACHE_TTL_IN_CACHE,
     INK_CACHE_AUTH_CONTENT,
     INK_CONGESTION,             /* congestion.config */
-    INK_FILTER_ALLOW,           /* filter.config */
-    INK_FILTER_DENY,
-    INK_FILTER_LDAP,
-    INK_FILTER_NTLM,
-    INK_FILTER_RADIUS,
-    INK_FILTER_KEEP_HDR,
-    INK_FILTER_STRIP_HDR,
     INK_HOSTING,                /* hosting.config */
     INK_ICP,                    /* icp.config */
     INK_IP_ALLOW,               /* ip_allow.config */
@@ -602,36 +593,6 @@ typedef enum
     INKAccessT access;          /* type of access allowed for user */
   } INKAdminAccessEle;
 
-/* arm_security.config */
-  typedef struct
-  {
-    INKCfgEle cfg_ele;
-    INKConnectT type_con;       /* determines if ports will be opened for TCP or UDP */
-    INKIpAddrEle *src_ip_addr;  /* arm-deny rule: the ip address or range of ip addresses that
-                                   will be denied access to ports (can be NULL);
-                                   arm-allow rule: the ip address or range of ip addressess
-                                   specifying the source of communication (can be NULL) */
-    INKIpAddrEle *dest_ip_addr; /* destination ip address (can be NULL) */
-    INKPortEle *open_ports;     /* open source ports (can be INVALID) */
-    INKPortEle *src_ports;      /* source ports (can be INVALID) */
-    /* arm-open rule: list of ports/port-ranges to open by default */
-    INKPortEle *dest_ports;     /* the destination port(s) that TCP traffic will be
-                                   allowed/denied access to (can be INVALID)  */
-    INKIntList src_port_list;   /* alternative for src_ports */
-    INKIntList dest_port_list;  /* alternative for dest_ports */
-  } INKArmSecurityEle;          /* + at least of src_ip_addr, dest_ip_addr, dest_ports,
-                                   src_ports is specified for arm allow rules;
-                                   + at least of dest_ports or src_ip_addr is specified for arm
-                                   deny rules */
-
-/* bypass.config */
-  typedef struct
-  {
-    INKCfgEle cfg_ele;
-    INKIpAddrList src_ip_addr;  /* source ip address (single or range) */
-    INKIpAddrList dest_ip_addr; /* destination ip address */
-  } INKBypassEle;
-
 /* cache.config */
   typedef struct
   {
@@ -662,23 +623,6 @@ typedef enum
     char *error_page_uri;
   } INKCongestionEle;
 
-/* filter.config */
-  typedef struct
-  {
-    INKCfgEle cfg_ele;
-    INKPdSsFormat filter_info;  /* general PdSs information */
-    INKHdrT hdr;                /* only valid if filter_act == INK_FILTER_xxx_HDR */
-    char *server;               /* 'auth_bypass': bypass pd_val || '<hostname>': authenticate pd_val against host */
-    char *dn;                   /* dn to use for authentication (not necessary if 'auth_bypass') */
-    char *realm;
-    char *uid_filter;           /* uid_filter to use for authentication (optional if server != 'auth_bypass'); defaults to "uid" */
-    char *attr;                 /* (optional) additional LDAP Attribute Name */
-    char *attr_val;             /* (optional) additional LDAP Attribute Value */
-    char *redirect_url;         /* (optional) */
-    char *bind_dn;              /* (optional) */
-    char *bind_pwd_file;        /* (optional) */
-  } INKFilterEle;
-
 /* hosting.config */
   typedef struct
   {
@@ -713,20 +657,6 @@ typedef enum
     INKIpAllowT action;
   } INKIpAllowEle;
 
-/* ipnat.conf */
-  typedef struct
-  {
-    INKCfgEle cfg_ele;
-    char *intr;                 /* ethernet interface name that user traffic will enter through */
-    INKIpAddr src_ip_addr;      /* the ip address user traffic is heading for */
-    int src_cidr;               /* the cidr of the source IP (optional) */
-    int src_port;               /* the port user traffic is heading to */
-    INKIpAddr dest_ip_addr;     /* the ip address to redirect traffic to */
-    int dest_port;              /* the port to redirect traffic to */
-    INKConnectT type_con;       /* udp or tcp */
-    INKProtocolT protocol;      /* (optional) user protocol, eg. dns */
-  } INKIpFilterEle;
-
 /* logs_xml.config */
   typedef struct
   {
@@ -1020,25 +950,16 @@ typedef enum
   inkapi void INKSspecDestroy(INKSspec * ele);
   inkapi INKPdSsFormat *INKPdSsFormatCreate();
   inkapi void INKPdSsFormatDestroy(INKPdSsFormat * ele);
-
   inkapi INKAdminAccessEle *INKAdminAccessEleCreate();
   inkapi void INKAdminAccessEleDestroy(INKAdminAccessEle * ele);
-  inkapi INKArmSecurityEle *INKArmSecurityEleCreate(INKRuleTypeT type);
-  inkapi void INKArmSecurityEleDestroy(INKArmSecurityEle * ele);
-  inkapi INKBypassEle *INKBypassEleCreate(INKRuleTypeT type);
-  inkapi void INKBypassEleDestroy(INKBypassEle * ele);
   inkapi INKCacheEle *INKCacheEleCreate(INKRuleTypeT type);
   inkapi void INKCacheEleDestroy(INKCacheEle * ele);
   inkapi INKCongestionEle *INKCongestionEleCreate();
   inkapi void INKCongestionEleDestroy(INKCongestionEle * ele);
-  inkapi INKFilterEle *INKFilterEleCreate(INKRuleTypeT type);
-  inkapi void INKFilterEleDestroy(INKFilterEle * ele);
   inkapi INKHostingEle *INKHostingEleCreate();
   inkapi void INKHostingEleDestroy(INKHostingEle * ele);
   inkapi INKIcpEle *INKIcpEleCreate();
   inkapi void INKIcpEleDestroy(INKIcpEle * ele);
-  inkapi INKIpFilterEle *INKIpFilterEleCreate();
-  inkapi void INKIpFilterEleDestroy(INKIpFilterEle * ele);
   inkapi INKIpAllowEle *INKIpAllowEleCreate();
   inkapi void INKIpAllowEleDestroy(INKIpAllowEle * ele);
   inkapi INKLogFilterEle *INKLogFilterEleCreate();

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/remote/APITestCliRemote.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/remote/APITestCliRemote.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/CliCreateCommands.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/CliCreateCommands.cc Fri Oct 22 16:05:00 2010
@@ -76,8 +76,6 @@ CliCreateCommands()
 
   createCommand("show:ssl", Cmd_ShowSsl, NULL, CLI_COMMAND_EXTERNAL, "show:ssl", "SSL configuration");
 
-  createCommand("show:filter", Cmd_ShowFilter, NULL, CLI_COMMAND_EXTERNAL, "show:filter", "Filter configuration");
-
   createCommand("show:parent", Cmd_ShowParents, CmdArgs_ShowParents, CLI_COMMAND_EXTERNAL,
                 "show:parent", "Parent configuration");
 
@@ -142,9 +140,6 @@ CliCreateCommands()
   createCommand("config:ssl", Cmd_ConfigSsl, CmdArgs_ConfigSsl, CLI_COMMAND_EXTERNAL,
                 "config:ssl status <on | off>\n" "config:ssl ports <int>", "Configure ssl");
 
-  createCommand("config:filter", Cmd_ConfigFilter, NULL, CLI_COMMAND_EXTERNAL,
-                "config:filter <url>", "Update filter.config rules <url>");
-
   createCommand("config:parent", Cmd_ConfigParents, CmdArgs_ConfigParents, CLI_COMMAND_EXTERNAL,
                 "config:parent status <on | off>\n"
                 "config:parent name <parent>\n" "config:parent rules <url>", "Update parent configuration");

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.cc Fri Oct 22 16:05:00 2010
@@ -612,45 +612,6 @@ CmdArgs_ConfigRestart()
   return 0;
 }
 
-////////////////////////////////////////////////////////////////
-// Cmd_ConfigFilter
-//
-// This is the callback function for the "config:filter" command.
-//
-// Parameters:
-//    clientData -- information about parsed arguments
-//    interp -- the Tcl interpreter
-//    argc -- number of command arguments
-//    argv -- the command arguments
-//
-int
-Cmd_ConfigFilter(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[])
-{
-  /* call to processArgForCommand must appear at the beginning
-   * of each command's callback function
-   */
-  if (processArgForCommand(interp, argc, argv) != CLI_OK) {
-    return CMD_ERROR;
-  }
-
-  if (processHelpCommand(argc, argv) == CLI_OK)
-    return CMD_OK;
-
-  if (cliCheckIfEnabled("config:filter") == CLI_ERROR) {
-    return CMD_ERROR;
-  }
-  cli_cmdCallbackInfo *cmdCallbackInfo;
-
-  cmdCallbackInfo = (cli_cmdCallbackInfo *) clientData;
-
-  Cli_Debug("Cmd_ConfigFilter argc %d\n", argc);
-
-  if (argc == 2) {
-    return (ConfigFilter(argv[1]));
-  }
-  Cli_Error(ERR_COMMAND_SYNTAX, cmdCallbackInfo->command_usage);
-  return CMD_ERROR;
-}
 
 ////////////////////////////////////////////////////////////////
 // Cmd_ConfigParents
@@ -2707,16 +2668,6 @@ ConfigPortsGet(int arg_ref)
   return CLI_OK;
 }
 
-// config filter sub-command
-int
-ConfigFilter(const char *url)
-{
-  Cli_Debug("ConfigFilter: url %s\n", url);
-
-  return (Cli_ConfigFileURL_Action(INK_FNAME_MGMT_ALLOW, "filter.config", url));
-  //   return (Cli_SetConfigFileFromUrl(INK_FNAME_FILTER, url));
-}
-
 int
 ConfigSecurityPasswd()
 {
@@ -5365,88 +5316,3 @@ find_value(const char *pathname, const c
 #endif
   return find;
 }
-
-int
-ConfigRadiusKeys(const char *record)
-{
-
-  char new_passwd1[256], new_passwd2[256], ch = ' ';
-  int i = 0;
-  INKError status = INK_ERR_OKAY;
-  INKActionNeedT action_need = INK_ACTION_UNDEFINED;
-  INKString old_pwd_file = NULL;
-  INKString dir_path = NULL;
-
-  // TODO: Use some proper getpass function here
-  //       depending on the system use either
-  //       getpass_r, getpassphrase or getpass
-  //       For platforms not having those
-  //       see apr_password_get
-  Cli_Debug("ConfigRadiusKeys\n");
-  Cli_Printf("\nEnter New Key:");
-  fflush(stdout);
-  i = 0;
-  ch = u_getch();
-  while (ch != '\n' && ch != '\r') {
-    new_passwd1[i] = ch;
-    i++;
-    ch = u_getch();
-
-  }
-  new_passwd1[i] = 0;
-
-  Cli_Printf("\nReEnter New Key:");
-  fflush(stdout);
-  i = 0;
-  ch = u_getch();
-  while (ch != '\n' && ch != '\r') {
-    new_passwd2[i] = ch;
-    i++;
-    ch = u_getch();
-
-  }
-  new_passwd2[i] = 0;
-
-  if (strcmp(new_passwd1, new_passwd2)) {
-    Cli_Printf("\nTwo New Keys Aren't the Same\n\n");
-    return CMD_ERROR;
-  }
-  Cli_Printf("\n");
-  status = Cli_RecordGetString(record, &old_pwd_file);
-  if (status != INK_ERR_OKAY) {
-    return CLI_ERROR;
-  }
-  if (old_pwd_file && strcasecmp(old_pwd_file, "NULL")) {
-    // remove the old_pwd_file
-    if (remove(old_pwd_file) != 0)
-      Cli_Debug("[ConfigRadiusKeys] Failed to remove password file %s", old_pwd_file);
-    xfree(old_pwd_file);
-  }
-  // XXX: Is this an absolute or config relative path
-  //      Usage here smells like absolute.
-  Cli_RecordGetString("proxy.config.auth.password_file_path", &dir_path);
-  if (!dir_path) {
-    Cli_Debug("[ConfigRadiusKeys] Failed to find the password file path.");
-    return CLI_ERROR;
-  }
-
-  char file_name[64];
-  char file_path[PATH_NAME_MAX + 1];
-  snprintf(file_name, 64, "pwd_%llu.enc", ink_microseconds(MICRO_REAL));
-  ink_filepath_make(file_path, sizeof(file_path), dir_path, file_name);
-  if (dir_path)
-    xfree(dir_path);
-
-  if (INKEncryptToFile(new_passwd1, file_path) != INK_ERR_OKAY) {
-    Cli_Debug("[ConfigRadiusKeys] Failed to encrypt and save the password.");
-  } else {
-    status = Cli_RecordSetString(record, (INKString) file_path, &action_need);
-    if (status) {
-      return status;
-    }
-    return (Cli_ConfigEnactChanges(action_need));
-  }
-
-  // Guessing that this will normally not happen, so return an error. /leif
-  return CLI_ERROR;
-}

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ConfigCmd.h Fri Oct 22 16:05:00 2010
@@ -366,18 +366,6 @@ int Cmd_ConfigRestart(ClientData clientD
 int CmdArgs_ConfigRestart();
 
 ////////////////////////////////////////////////////////////////
-// Cmd_ConfigFilter
-//
-// This is the callback function for the "config:filter" command.
-//
-// Parameters:
-//    clientData -- information about parsed arguments
-//    interp -- the Tcl interpreter
-//    argc -- number of command arguments
-//    argv -- the command arguments
-//
-int Cmd_ConfigFilter(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
-////////////////////////////////////////////////////////////////
 // Cmd_ConfigParents
 //
 // This is the callback function for the "config:parents" command.
@@ -822,9 +810,6 @@ int ConfigTimezone(int, int);
 //config Timezone List
 int ConfigTimezoneList();
 
-// config filter sub-command
-int ConfigFilter(const char *url);
-
 // config security password sub-command
 int ConfigSecurityPasswd();
 

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.cc Fri Oct 22 16:05:00 2010
@@ -576,35 +576,6 @@ Cmd_ShowSsl(ClientData clientData, Tcl_I
   return (ShowSsl());
 }
 
-////////////////////////////////////////////////////////////////
-// Cmd_ShowFilter
-//
-// This is the callback function for the "show:filter" command.
-//
-// Parameters:
-//    clientData -- information about parsed arguments
-//    interp -- the Tcl interpreter
-//    argc -- number of command arguments
-//    argv -- the command arguments
-//
-int
-Cmd_ShowFilter(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[])
-{
-  NOWARN_UNUSED(clientData);
-  /* call to processArgForCommand must appear at the beginning
-   * of each command's callback function
-   */
-  if (processArgForCommand(interp, argc, argv) != CLI_OK) {
-    return CMD_ERROR;
-  }
-
-  if (processHelpCommand(argc, argv) == CLI_OK)
-    return CMD_OK;
-
-  Cli_Debug("Cmd_ShowFilter\n");
-
-  return (ShowFilter());
-}
 
 ////////////////////////////////////////////////////////////////
 // Cmd_ShowParents
@@ -1933,19 +1904,6 @@ ShowSsl()
   return CLI_OK;
 }
 
-// show filter sub-command
-int
-ShowFilter()
-{
-  // display rules from filter.config
-  Cli_Printf("\n");
-
-  Cli_Printf("filter.config rules\n" "-------------------\n");
-  INKError status = Cli_DisplayRules(INK_FNAME_FILTER);
-  Cli_Printf("\n");
-
-  return status;
-}
 
 // show parents sub-command
 int

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.h
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.h?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.h (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/ShowCmd.h Fri Oct 22 16:05:00 2010
@@ -111,7 +111,6 @@ int Cmd_ShowHostDb(ClientData clientData
 int Cmd_ShowDnsResolver(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
 int Cmd_ShowLogging(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
 int Cmd_ShowSsl(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
-int Cmd_ShowFilter(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
 int Cmd_ShowParents(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
 int CmdArgs_ShowParents();
 int Cmd_ShowRemap(ClientData clientData, Tcl_Interp * interp, int argc, const char *argv[]);
@@ -196,9 +195,6 @@ int ShowLogging();
 // show ssl sub-command
 int ShowSsl();
 
-// show filter sub-command
-int ShowFilter();
-
 // show parents sub-command
 int ShowParents();
 

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_detailed_command_list.txt
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_detailed_command_list.txt?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_detailed_command_list.txt (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_detailed_command_list.txt Fri Oct 22 16:05:00 2010
@@ -554,17 +554,6 @@ ssl			SSL Ports
   Restrict SSL Connections to Ports -- 443 563   (proxy.config.http.ssl_ports)
   ts>
 
-filter			Filter Rules
-  syntax: show:filter
-  args:   none
-  behavior:  Display filtering configuration.
-
-  ts> show:filter
-  filter.config rules
-  -------------------
-  (Display rules from filter.config)
-  ts> 
-
 parent			Parent Configuration
 			(on/off, parents, rules)
   syntax: show:parent
@@ -1371,11 +1360,6 @@ logging			Logging Configuration
     ts#
 
 ssl			SSL Ports
-filter			Filter Rules
-  syntax: config:filter <url>
-
-    ts# config:filter http://example.com/filter.config
-    ts#
 
 security		Security Configuration
 			(TS IP allow, MGMT allow, Admin Access)

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_feature_spec.txt
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_feature_spec.txt?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_feature_spec.txt (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/cli_feature_spec.txt Fri Oct 22 16:05:00 2010
@@ -96,7 +96,6 @@ show:hostdb                  Host databa
 show:dns-resolver            DNS resolver configuration
 show:logging                 Logging configuration
 show:ssl                     SSL configuration
-show:filter                  Filter configuration
 show:parent                  Parent configuration
 show:remap                   Remap configuration
 show:socks                   SOCKS configuration
@@ -125,8 +124,6 @@ config:stop                    Stop prox
 config:ssl <on | off>
 config:ssl ports <int>      
 
-config:filter <url>            Update filter.config rules <url>
-
 config:parent <on | off>    
 config:parent name <parent>
 config:parent rules <url>    

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cluster/ClusterCom.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cluster/ClusterCom.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cluster/ClusterCom.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cluster/ClusterCom.cc Fri Oct 22 16:05:00 2010
@@ -1597,7 +1597,7 @@ ClusterCom::constructSharedFilePacket(ch
     Rollback *rb;
 
     /* Some files are local only */
-    if (strcmp(line, "ipnat.conf") == 0 || strcmp(line, "storage.config") == 0 ||
+    if (strcmp(line, "storage.config") == 0 ||
         strcmp(line, "lm.config") == 0 ||       // legacy: should remove
         strcmp(line, "internal.config") == 0) { // legacy: should remove
       continue;

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/Makefile.am
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/Makefile.am?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/Makefile.am (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/Makefile.am Fri Oct 22 16:05:00 2010
@@ -17,9 +17,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-AM_CPPFLAGS = \
-  $(iocore_include_dirs) \
-  -DPKGSYSUSER=\"$(pkgsysuser)\"
+AM_CPPFLAGS = $(iocore_include_dirs)
 
 MGMT_DEFS = @MGMT_DEFS@
 DEFS += $(MGMT_DEFS)

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/TrafficCop.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/TrafficCop.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/TrafficCop.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/cop/TrafficCop.cc Fri Oct 22 16:05:00 2010
@@ -26,12 +26,12 @@
 #include "I_Version.h"
 
 #if defined(linux)
-// XXX: Nuke multiple includes
 #include "sys/utsname.h"
 #include "ink_killall.h"
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/sem.h>
+
 union semun
 {
   int val;                      /* value for SETVAL */
@@ -78,8 +78,7 @@ static char syslog_fac_str[PATH_MAX];
 static int killsig = SIGKILL;
 static int coresig = 0;
 
-static char sys_user[80] = PKGSYSUSER;
-static char admin_user[80] = PKGSYSUSER;
+static char admin_user[80] = TS_PKGSYSUSER;
 static char manager_binary[PATH_MAX] = "traffic_manager";
 static char server_binary[PATH_MAX] = "traffic_server";
 static char manager_options[OPTIONS_LEN_MAX] = "";
@@ -642,16 +641,9 @@ read_config()
   }
 
   build_config_table(fp);
-
   fclose(fp);
 
-  // Get the admin user
   read_config_string("proxy.config.admin.user_id", admin_user, sizeof(admin_user));
-  // just warn if the admin user is not the configured system user
-  if (strncmp(sys_user, admin_user, sizeof(admin_user)) != 0) {
-    cop_log(COP_WARNING, "proxy.config.admin.user_id should be \"%s\"",sys_user);
-  }
-
   read_config_string("proxy.config.manager_binary", manager_binary, sizeof(manager_binary));
   read_config_string("proxy.config.proxy_binary", server_binary, sizeof(server_binary));
   read_config_string("proxy.config.bin_path", bin_path, sizeof(bin_path));

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/configure/Makefile.am
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/configure/Makefile.am?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/configure/Makefile.am (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/configure/Makefile.am Fri Oct 22 16:05:00 2010
@@ -37,7 +37,6 @@ dist_webui_DATA = \
 	c_header.ink \
 	c_http_cachability.ink \
 	c_http_dyn_cache.ink \
-	c_http_filtering.ink \
 	c_http_general.ink \
 	c_http_parent_proxy.ink \
 	c_http_privacy.ink \
@@ -94,14 +93,11 @@ dist_webui_DATA = \
 	c_windows_media_general.ink \
 	c_windows_media_mbridge.ink \
 	c_windows_media_mcast.ink \
-	f_bypass_config.ink \
 	f_cache_config.ink \
 	f_configs.ink \
-	f_filter_config.ink \
 	f_hosting_config.ink \
 	f_icp_config.ink \
 	f_ip_allow_config.ink \
-	f_ipnat_config.ink \
 	f_mgmt_allow_config.ink \
 	f_parent_config.ink \
 	f_partition_config.ink \

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml Fri Oct 22 16:05:00 2010
@@ -343,9 +343,6 @@
         <LINK name="Throttling" refresh="false"
               file_link="/configure/c_throttling.ink"
               help_link="/help/ts.ink?help=c_cmng.htm"/>
-        <LINK name="Load Shedding" refresh="false"
-              file_link="/configure/c_arm_load_shedding.ink"
-              help_link="/help/ts.ink?help=c_cmng.htm"/>
         <LINK name="Congestion Control" refresh="false"
               file_link="/configure/c_congestion.ink"
               help_link="/help/ts.ink?help=c_cmng.htm"/>

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml.win
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml.win?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml.win (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/navigation_tree.xml.win Fri Oct 22 16:05:00 2010
@@ -111,11 +111,6 @@
     </MENU>
 
     <MENU name="Networking">
-      <ITEM name="ARM" enable_record="proxy.config.arm.enabled">
-        <LINK refresh="true"
-              file_link="/monitor/m_arm.ink"
-              help_link="/help/ts.ink?help=s_arm.htm"/>
-      </ITEM>
       <ITEM name="DNS Resolver">
         <LINK refresh="true"
               file_link="/monitor/m_dns.ink"
@@ -261,9 +256,6 @@
         <LINK name="Proxy Access" refresh="false"
               file_link="/configure/c_proxy_access.ink"
               help_link="/help/ts.ink?help=c_cnct.htm"/>
-        <LINK name="ARM Security" refresh="false"
-              file_link="/configure/c_arm_security.ink"
-              help_link="/help/ts.ink?help=c_cnct.htm"/>
       </ITEM>
       <ITEM name="SSL Termination" enable_record="proxy.config.ssl.enabled">
         <LINK name="General" refresh="false"
@@ -321,17 +313,6 @@
     </MENU>
 
     <MENU name="Networking">
-      <ITEM name="ARM" enable_record="proxy.config.arm.enabled">
-        <LINK name="General" refresh="false"
-              file_link="/configure/c_arm_general.ink"
-              help_link="/help/ts.ink?help=c_armo.htm"/>
-        <LINK name="Static Bypass" refresh="false"
-              file_link="/configure/c_arm_static_bypass.ink"
-              help_link="/help/ts.ink?help=c_armo.htm"/>
-        <LINK name="Dynamic Bypass" refresh="false"
-              file_link="/configure/c_arm_dynamic_bypass.ink"
-              help_link="/help/ts.ink?help=c_armo.htm"/>
-      </ITEM>
       <ITEM name="DNS Resolver">
         <LINK name="Resolver" refresh="false"
               file_link="/configure/c_dns_resolver.ink"

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/tune/navigation_tree.xmlcpp
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/tune/navigation_tree.xmlcpp?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/tune/navigation_tree.xmlcpp (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/html2/tune/navigation_tree.xmlcpp Fri Oct 22 16:05:00 2010
@@ -404,9 +404,6 @@ This text will be stripped from the buil
         <LINK name="Throttling" refresh="false"
               file_link="/configure/c_throttling.ink"
               help_link="/help/ts.ink?help=c_cmng.htm"/>
-        <LINK name="Load Shedding" refresh="false"
-              file_link="/configure/c_arm_load_shedding.ink"
-              help_link="/help/ts.ink?help=c_cmng.htm"/>
         <LINK name="Congestion Control" refresh="false"
               file_link="/configure/c_congestion.ink"
               help_link="/help/ts.ink?help=c_cmng.htm"/>

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/utils/MgmtConverter.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/utils/MgmtConverter.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/utils/MgmtConverter.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/utils/MgmtConverter.cc Fri Oct 22 16:05:00 2010
@@ -71,7 +71,6 @@ const char *config_files[] = {
   "hosting.config",
   "icp.config",
   "ip_allow.config",
-  "ipnat.conf",
   "mgmt_allow.config",
   "parent.config",
   "partition.config",
@@ -597,8 +596,6 @@ convertPartitionRule_xml(XMLNode * rule_
 
   if (strcmp(rule_node->getNodeName(), "http") == 0) {
     ele->scheme = INK_PARTITION_HTTP;
-  } else if (strcmp(rule_node->getNodeName(), "mixt") == 0) {
-    ele->scheme = INK_PARTITION_MIXT;
   } else {
     INKPartitionEleDestroy(ele);
     return NULL;
@@ -1605,9 +1602,6 @@ convertPartitionRule_ts(INKCfgEle * cfg_
   case INK_PARTITION_HTTP:
     writeXmlAttrStartTag(xml_file, "http");
     break;
-  case INK_PARTITION_MIXT:
-    writeXmlAttrStartTag(xml_file, "mixt");
-    break;
   default:
     goto Lerror;
   }
@@ -1630,9 +1624,6 @@ convertPartitionRule_ts(INKCfgEle * cfg_
   case INK_PARTITION_HTTP:
     writeXmlEndTag(xml_file, "http");
     break;
-  case INK_PARTITION_MIXT:
-    writeXmlEndTag(xml_file, "mixt");
-    break;
   default:
     break;
   }
--- trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/remote/APITestCliRemote.cc (original)
+++ trafficserver/traffic/branches/wccp/proxy/mgmt2/api2/remote/APITestCliRemote.cc Fri Oct 22 16:05:00 2010
@@ -43,8 +43,8 @@
  *
  * File operations:
  * ---------------
  * read_file:  reads filter.config file
  * write_file: write some made-up text to filter.config file
  * proxy.config.xxx (a records.config variable): returns value of that record
  * records: tests get/set/get a record of each different type
  *          (int, float, counter, string)
@@ -411,54 +411,6 @@ print_admin_access_ele(INKAdminAccessEle
 }
 
 void
-print_arm_security_ele(INKArmSecurityEle * ele)
-{
-  if (!ele) {
-    printf("can't print ele\n");
-  }
-
-  printf("Connection type: %d\n", ele->type_con);
-  print_ip_addr_ele(ele->src_ip_addr);
-  print_ip_addr_ele(ele->dest_ip_addr);
-  print_ports(ele->open_ports);
-  print_ports(ele->src_ports);
-  print_ports(ele->dest_ports);
-}
-
-void
-print_bypass_ele(INKBypassEle * ele)
-{
-  if (!ele) {
-    printf("can't print ele\n");
-  }
-
-  char buf[MAX_BUF_SIZE];
-  bzero(buf, MAX_BUF_SIZE);
-  strncat(buf, "bypass ", sizeof(buf) - strlen(buf) - 1);
-  char *str_list;
-
-  if (ele->src_ip_addr) {
-    snprintf(buf, sizeof(buf), "src ");
-    str_list = ip_addr_list_to_string((IpAddrList *) ele->src_ip_addr, ",");
-    strncat(buf, str_list, sizeof(buf) - strlen(buf) - 1);
-    xfree(str_list);
-  }
-
-  if (ele->dest_ip_addr) {
-    if (ele->src_ip_addr) {
-      strncat(buf, " AND ", sizeof(buf) - strlen(buf) - 1);
-    }
-    strncat(buf, "dst ", sizeof(buf) - strlen(buf) - 1);
-    str_list = ip_addr_list_to_string((IpAddrList *) ele->dest_ip_addr, ",");
-    strncat(buf, str_list, sizeof(buf) - strlen(buf) - 1);
-    xfree(str_list);
-  }
-
-  printf("%s\n", buf);
-  return;
-}
-
-void
 print_cache_ele(INKCacheEle * ele)
 {
   if (!ele) {
@@ -525,59 +477,6 @@ print_cache_ele(INKCacheEle * ele)
   return;
 }
 
-void
-print_filter_ele(INKFilterEle * ele)
-{
-  if (!ele) {
-    printf("can't print ele\n");
-  }
-
-  // now format the message
-  switch (ele->cfg_ele.type) {
-  case INK_FILTER_ALLOW:
-    printf("action=allow\t");
-    break;
-  case INK_FILTER_DENY:
-    printf("action=deny\t");
-    break;
-  case INK_FILTER_KEEP_HDR:
-    printf("keep_hdr=\t");
-    break;
-  case INK_FILTER_STRIP_HDR:
-    printf("strip_hdr=\t");
-    break;
-  default:                     /* invalid action directive */
-    return;
-  }
-
-  // Just for keep_hdr or strip_hdr
-  switch (ele->cfg_ele.type) {
-  case INK_FILTER_KEEP_HDR:
-  case INK_FILTER_STRIP_HDR:
-    switch (ele->hdr) {
-    case INK_HDR_DATE:
-      printf("date\n");
-      break;
-    case INK_HDR_HOST:
-      printf("host\n");
-      break;
-    case INK_HDR_COOKIE:
-      printf("cookie\n");
-      break;
-    case INK_HDR_CLIENT_IP:
-      printf("client_ip\n");
-      break;
-    default:
-      return;
-    }
-  default:
-    break;
-  }
-
-  print_pd_sspec(ele->filter_info);
-
-  return;
-}
 
 void
 print_hosting_ele(INKHostingEle * ele)
@@ -649,17 +548,6 @@ print_ip_allow_ele(INKIpAllowEle * ele)
 }
 
 void
-print_ipnat_ele(INKIpFilterEle * ele)
-{
-  if (!ele) {
-    printf("can't print ele\n");
-  }
-
-
-  printf("%s; %s:%d; %s:%d\n", ele->intr, ele->src_ip_addr, ele->src_port, ele->dest_ip_addr, ele->dest_port);
-}
-
-void
 print_mgmt_allow_ele(INKMgmtAllowEle * ele)
 {
   if (!ele) {
@@ -976,9 +864,6 @@ print_ele_list(INKFileNameT file, INKCfg
     case INK_FNAME_CACHE_OBJ:
       print_cache_ele((INKCacheEle *) ele);
       break;
-    case INK_FNAME_FILTER:
-      print_filter_ele((INKFilterEle *) ele);
-      break;
     case INK_FNAME_HOSTING:
       print_hosting_ele((INKHostingEle *) ele);
       break;
@@ -1658,7 +1543,7 @@ test_read_file()
   int f_ver = -1;
 
   printf("\n");
-  if (INKConfigFileRead(INK_FNAME_FILTER, &f_text, &f_size, &f_ver) != INK_ERR_OKAY)
+  if (INKConfigFileRead(INK_FNAME_HOSTING, &f_text, &f_size, &f_ver) != INK_ERR_OKAY)
     printf("[INKConfigFileRead] FAILED!\n");
   else {
     printf("[INKConfigFileRead]\n\tFile Size=%d, Version=%d\n%s\n", f_size, f_ver, f_text);
@@ -1683,14 +1568,14 @@ test_write_file()
   int new_f_size = strlen(new_f_text);
 
   printf("\n");
-  if (INKConfigFileWrite(INK_FNAME_FILTER, new_f_text, new_f_size, -1) != INK_ERR_OKAY)
+  if (INKConfigFileWrite(INK_FNAME_HOSTING, new_f_text, new_f_size, -1) != INK_ERR_OKAY)
     printf("[INKConfigFileWrite] FAILED!\n");
   else
     printf("[INKConfigFileWrite] SUCCESS!\n");
   printf("\n");
 
   // should free f_text???
-  if (INKConfigFileRead(INK_FNAME_FILTER, &f_text, &f_size, &f_ver) != INK_ERR_OKAY)
+  if (INKConfigFileRead(INK_FNAME_HOSTING, &f_text, &f_size, &f_ver) != INK_ERR_OKAY)
     printf("[INKConfigFileRead] FAILED!\n");
   else {
     printf("[INKConfigFileRead]\n\tFile Size=%d, Version=%d\n%s\n", f_size, f_ver, f_text);
@@ -1725,8 +1610,6 @@ test_cfg_context_get(char *args)
     file = INK_FNAME_CACHE_OBJ;
   } else if (strcmp(name, "congestion.config") == 0) {
     file = INK_FNAME_CONGESTION;
-  } else if (strcmp(name, "filter.config") == 0) {
-    file = INK_FNAME_FILTER;
   } else if (strcmp(name, "hosting.config") == 0) {
     file = INK_FNAME_HOSTING;
   } else if (strcmp(name, "icp.config") == 0) {
@@ -1803,8 +1686,6 @@ test_cfg_context_move(char *args)
     file = INK_FNAME_CACHE_OBJ;
   } else if (strcmp(name, "congestion.config") == 0) {
     file = INK_FNAME_CONGESTION;
-  } else if (strcmp(name, "filter.config") == 0) {
-    file = INK_FNAME_FILTER;
   } else if (strcmp(name, "hosting.config") == 0) {
     file = INK_FNAME_HOSTING;
   } else if (strcmp(name, "icp.config") == 0) {
@@ -43,8 +43,8 @@
  * File operations:
  * ---------------
- * read_file:  reads filter.config file
- * write_file: write some made-up text to filter.config file
+ * read_file:  reads hosting.config file
+ * write_file: write some made-up text to hosting.config file
  * proxy.config.xxx (a records.config variable): returns value of that record
  * records: tests get/set/get a record of each different type

Modified: trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/CliCreateCommands.cc
URL: http://svn.apache.org/viewvc/trafficserver/traffic/branches/wccp/proxy/mgmt2/cli2/CliCreateCommands.cc?rev=1026389&r1=1026388&r2=1026389&view=diff
==============================================================================